Plover Stenograph USB
=====================

Use Stenograph machines such as the Luminex, Diamanté, and Protégé on Plover. The plugin may
not work with other machines.

Special thanks to Keith McCready for his guidance and support.

Tested Machines
---------------

If you test another machine, please let me know whether it works or not.

- Working
  - Luminex
  - Diamanté
  - Protégé
- Not Working
  - Unknown

Get the Drivers
---------------

-  On Windows, install the `Stenograph USB Drivers`_ (`direct link`_)
-  On Mac and Linux, the plugin should work without additional software as we package libusb

Installation
------------

The plugin is available to install from within Plover 4 using the
Plugins Manager.

.. _Stenograph USB Drivers: http://www.stenograph.com/utilities-links-downloads
.. _direct link: http://www.stenograph.com/content/files/documents/USB_Writer_Drivers.zip

Changelog
---------

v1.2.0:

- Package libusb to remove the need to install it on Mac and Linux

v1.1.0:

- Reduce CPU usage
- Fix support for 64-bit Windows
